@@ -285,7 +285,7 @@ def _entry_disposition(response_headers, request_headers):
         retval = "STALE"
     elif cc.has_key('only-if-cached'):
         retval = "FRESH"
-    elif response_headers.has_key('date'):
+    elif response_headers.has_key('date') and response_headers['date'].strip() is not "":
         date = calendar.timegm(email.Utils.parsedate_tz(response_headers['date']))
         now = time.time()
         current_age = max(0, now - date)
