@@ -1,4 +1,6 @@
-import gobject
+import gobject, logging
+
+_logger = logging.getLogger("bigboard.libbig.polling")
 
 class Task:
     def __init__(self, interval_msecs, initial_interval=-1):
@@ -19,6 +21,7 @@ class Task:
     def __do_periodic_task_if_not_pending(self):
          # pending flag is to prevent "pile up" if we spend longer than the interval on the task
         if self.__pending: 
+            _logger.debug("Pending, returning")
             return True
 
         self.__pending = True
