@@ -94,7 +94,7 @@ def fmt_canvas_text(canvas_text, is_today, is_over, color=None):
         canvas_text.set_property("attributes", attrs)   
     # stuff for today is bold
     if is_today:
-        canvas_text.set_property("font", "13px Bold")
+        canvas_text.set_property("classes", "today")
 
 def compare_by_date(event_a, event_b):
     return cmp(event_a.get_start_time(), event_b.get_start_time())
@@ -321,31 +321,55 @@ class EventDetailsDisplay(hippo.CanvasBox):
        
     def __init__(self, event, calendar_dict_list, **kwargs):
         kwargs['orientation'] = hippo.ORIENTATION_VERTICAL
-        kwargs['border'] = 1
-        kwargs['border-color'] = 0x000000ff
         hippo.CanvasBox.__init__(self, **kwargs)
         self.__event = event
         self.__calendar_dict_list = calendar_dict_list
         color = event.get_color()
-        end_color=0xc8c8c8ff
-        if color is not None:
-            # the color is in the format '#FFFFFF' 
-            end_color = int(color[1:7], 16) * 0x100 + 0xff
 
-        self.__header = hippo.CanvasGradient(orientation=hippo.ORIENTATION_HORIZONTAL,
-                                             start_color=0xf2f2f2f2,
-                                             end_color=end_color)
+        # We used to make the top box a gradient incorporating the event
+        # color, but that doesn't work well with themes with customized
+        # slideouts. So we just make the event color the foreground color
+        # as we do in the main list. It might be nice to be able to detect
+        # the default square/white theme (Milky) and use the colored gradient
+        # style.
 
+#         end_color=0xc8c8c8ff
+#         if color is not None:
+#             # the color is in the format '#FFFFFF' 
+#             end_color = int(color[1:7], 16) * 0x100 + 0xff
+
+#         self.__header = hippo.CanvasGradient(orientation=hippo.ORIENTATION_HORIZONTAL,
+#                                              start_color=0xf2f2f2f2,
+#                                              end_color=end_color)
+        self.__header = hippo.CanvasBox(orientation=hippo.ORIENTATION_HORIZONTAL,
+                                        xalign=hippo.ALIGNMENT_CENTER,
+                                        classes='slideout-header')
         self.append(self.__header)
-        event_link = ActionLink(text=self.__get_title(), font="14px", padding=4)
-        event_link.connect("activated", self.__on_activate_web)
+        event_link = ActionLink(text=self.__get_title())
+        if color != None:
+            rgba = int(color[1:7], 16) * 0x100 + 0xff
+            r = (rgba & 0xff000000) >> 24
+            b = (rgba & 0x00ff0000) >> 16
+            g = (rgba & 0x0000ff00) >> 8
+            event_link.props.color = int(color[1:7], 16) * 0x100 + 0xff
+            # If the event color is dark, use a white background and gray border
+            # Standard color => grayscale formula - http://en.wikipedia.org/wiki/Grayscale
+            # depends obviously on exact monitor calibration, etc
+            #
+            # This is going to look a little silly for white background themes;
+            # we probably need a way for a theme to tell us that it is dark or light
+            # 
+            if 0.3 * r + 0.59 * g + 0.11 * r < 128:
+                event_link.props.background_color = 0xffffffff;
+                event_link.props.padding_left = 4
+                event_link.props.padding_right = 4
+                event_link.props.border = 1
+                event_link.props.border_color = 0x888888ff;
 
-        attrs = pango.AttrList()
-        attrs.insert(pango.AttrForeground(0xFFFF, 0xFFFF, 0xFFFF, 0, 0xFFFF))
-        event_link.set_property("attributes", attrs)   
+        event_link.connect("activated", self.__on_activate_web)
         self.__header.append(event_link)
 
-        self.__top_box = hippo.CanvasBox(orientation=hippo.ORIENTATION_VERTICAL, spacing=4, border_top=4, border_bottom=4)
+        self.__top_box = hippo.CanvasBox(orientation=hippo.ORIENTATION_VERTICAL, spacing=4, classes="slideout-main")
         self.append(self.__top_box)
         event_time = hippo.CanvasText(xalign=hippo.ALIGNMENT_START, padding_left=4, padding_right=4, text="for: " + fmt_datetime_interval(event.get_start_time(), event.get_end_time()))
         self.__top_box.append(event_time)
@@ -556,7 +580,7 @@ class CalendarStock(AbstractMugshotStock, google_stock.GoogleStock):
                 #  you must first close the existing Firefox process, or restart your system."
                 time.sleep(2)
                 done_with_sleep_state = 2  
-            libbig.show_url(create_account_url(google_account.get_account().get_username_as_google_email()))
+            libbig.show_url(create_account_url(google_account.get_account().GetUsername()))
             if done_with_sleep_state == 0:
                 done_with_sleep_state = 1
         
@@ -784,7 +808,7 @@ class CalendarStock(AbstractMugshotStock, google_stock.GoogleStock):
         _logger.debug("have a google login, refreshing events")
         title = hippo.CanvasText(xalign=hippo.ALIGNMENT_START, size_mode=hippo.CANVAS_SIZE_ELLIPSIZE_END)
         title.set_property("text", fmt_date(self.__day_displayed))
-        title.set_property("font", "13px Bold")
+        title.set_property("id", "event-title")
         self.__box.append(title) 
 
         content_box = hippo.CanvasBox(orientation=hippo.ORIENTATION_HORIZONTAL)
@@ -1057,7 +1081,7 @@ class CalendarStock(AbstractMugshotStock, google_stock.GoogleStock):
             self.__slideout_event = None
             return True
 
-        self.__slideout = slideout.ThemedSlideout()
+        self.__slideout = slideout.Slideout()
         self.__slideout_event = event
         coords = event.get_screen_coords()
         # _logger.debug("coords are %s %s; allocation alone %s", self.__box.get_context().translate_to_screen(self.__box)[0] + self.__box.get_allocation()[0] + 4, coords[1], event.get_allocation())
